The ``klio-cli``
================

.. image:: https://img.shields.io/pypi/v/klio-cli?color=%2300aa55&label=klio-cli
   :target: https://pypi.org/project/klio-cli
   :alt: Latest version of klio-cli on PyPI

.. image:: https://github.com/spotify/klio/workflows/klio-cli%20unit%20tests/badge.svg
   :target: https://github.com/spotify/klio/actions?query=workflow%3A%22klio-cli+unit+tests%22
   :alt: Status of klio-cli unit tests


.. start-klio-cli-intro

The CLI is the main entrypoint for users in interacting with a Klio job.
This CLI is used for creating, deploying, testing, and profiling of Klio jobs, among other helpful commands.

Check out the `installation guide <https://docs.klio.io/en/latest/quickstart/installation.html>`_ for how to setup installation.
There is also the `user guide <https://docs.klio.io/en/latest/userguide/index.html>`_ and the `API documentation <https://docs.klio.io/en/latest/reference/cli/index.html>`_ for more information.
